==> RcmdrPlugin.NMBU_1.7.0.tar.gz: RcmdrPlugin.NMBU/R/globals.R <==
#%% $Id: globals.R 35 2014-01-10 21:17:26Z khliland $
# Borrowed and adapted from Rcmdr 

if (getRversion() >= "2.15.1")  
    globalVariables(c("top", "buttonsFrame", "byOutVariable", "repsOutVariable", "helpButton", ".Z",
		"subsetVariable", "linQuadVariable", "priorVariable", "g", "cvVariable", "displayPredVariable",
		"savePredVariable", "displayPostVariable", "savePostVariable", "subsetFrame", "linQuadFrame",
		"covariancesVariable", "covCorVariable", "covariancesFrame", "covCorFrame", "meanVariable",
		"medianVariable", "sumVariable", "sumSqVariable", "sdVariable", "sdErrVariable", "varVariable",
		"skewnessVariable", "kurtosisVariable", "typeButtonsVariable", ".groups", "checkBoxFrame",
		"skCheckBoxFrame", "typeButtonsFrame", "groupsFrame", "percentsVariable", "chisqTestVariable",
		"chisqComponentsVariable", "expFreqVariable", "fisherTestVariable", ".Test", ".Table", "percentsFrame",
		"testsFrame", "chisqVariable", "fisherVariable", "singleSampleZTest", "alternativeVariable",
		"alternativeFrame", "independentSamplesZTest", "variancesVariable", "variancesFrame", "pairedZTest",
		"singleSampleTTest", "independentSamplesTTest", "pairedTTest", "oneWayAnova", ".Pairs", "multiWayAnova",
		"testVariable", "testVerVariable", "testFrame", "testVerFrame", "centerVariable", "scaleVariable",
		"Relcomp", "optionsFrame", "methodVariable", "distanceTypeVariable", "hierarchicalCluster",
		"distanceTypeFrame", "methodFrame", "plotVariable", "linearVariable", "lhsVariable", "rhsVariable",
		"xBox", "outerOperatorsFrame", "formulaFrame", "lhsEntry", "modelTypeVariable", "modelTypeFrame",
		"subdialog", "subButtonsFrame", "onHelp", "correlationsVariable", "screeplotVariable", "addPCVariable",
		"principalComponents", "validationVariable", "jackknifeVariable", "pcrplsrVariable", "addCompVariable",
		"validationFrame", "pcrplsrFrame", "contrVariable", "regVariable", "typeVariable", "typeVariable",
		"typeVariable", "typeRVariable", "linearModelANOVA", "linearModel", "contrFrame", "lineTypeVariable",
		"onCancel", "lineTypeFrame", "stackedVariable", "commonscaleVariable", "my.lm", "plottypeVariable",
		"plottypeFrame", "label.formatVariable", "zoomedVariable", "discreteVariable", "tmp", "scaleFrame",
		"meansVariable", "boxPlot", "fullmodelVariable", ".commander", "fittedVariable", "residualsVariable",
		"stdresVariable", "studresVariable", "pearsonVariable", "spearsonVariable", "hatvaluesVariable",
		"dffitsVariable", "cookdVariable", "obsNumbersVariable", "selectFrame", "typeVariable", "extrapVariable",
		"tukeyTestsVariable", "tukeyGroupsVariable", "bonferroniTestsVariable", "bonferroniGroupsVariable",
		"fisherTestsVariable", "fisherGroupsVariable", "tukeyFrame", "bonferroniFrame", "fisherFrame",
		"storeVariable", "displayVariable", "axis.crossVariable", "namesVariable", "spectraVariable",
		"regionsVariable", "contoursVariable", "samplesVariable", "logVariable", "logFrame", "rgl.cur",
		"outmat,rss,rsq,adjr2", "cp", ".x", "type1Variable", "type2Variable", "type3Variable", "mix.model",
		"base", "high", "newDataSet", ".activeDataSet", ".activeModel", ".activeDataSet","outmat","rss",
		"rsq","adjr2","pushViewport","viewport","upViewport","pressresVariable","presspredVariable",
		 "selectFrame1", "selectFrame2", "selectFrame3", "selectFrame4", "selectFrame5", "selectFrame6",
		 ".groups",".levels","multinom","typeFrame", "tkget", "tktag.add", "tkyview.moveto"))

==> RcmdrPlugin.NMBU_1.7.2.tar.gz: RcmdrPlugin.NMBU/R/globals.R <==
#%% $Id: globals.R 35 2014-01-10 21:17:26Z khliland $
# Borrowed and adapted from Rcmdr 

if (getRversion() >= "2.15.1")  
    globalVariables(c("top", "buttonsFrame", "byOutVariable", "repsOutVariable", "helpButton", ".Z",
		"subsetVariable", "linQuadVariable", "priorVariable", "g", "cvVariable", "displayPredVariable",
		"savePredVariable", "displayPostVariable", "savePostVariable", "subsetFrame", "linQuadFrame",
		"covariancesVariable", "covCorVariable", "covariancesFrame", "covCorFrame", "meanVariable",
		"medianVariable", "sumVariable", "sumSqVariable", "sdVariable", "sdErrVariable", "varVariable",
		"skewnessVariable", "kurtosisVariable", "typeButtonsVariable", ".groups", "checkBoxFrame",
		"skCheckBoxFrame", "typeButtonsFrame", "groupsFrame", "percentsVariable", "chisqTestVariable",
		"chisqComponentsVariable", "expFreqVariable", "fisherTestVariable", ".Test", ".Table", "percentsFrame",
		"testsFrame", "chisqVariable", "fisherVariable", "singleSampleZTest", "alternativeVariable",
		"alternativeFrame", "independentSamplesZTest", "variancesVariable", "variancesFrame", "pairedZTest",
		"singleSampleTTest", "independentSamplesTTest", "pairedTTest", "oneWayAnova", ".Pairs", "multiWayAnova",
		"testVariable", "testVerVariable", "testFrame", "testVerFrame", "centerVariable", "scaleVariable",
		"Relcomp", "optionsFrame", "methodVariable", "distanceTypeVariable", "hierarchicalCluster",
		"distanceTypeFrame", "methodFrame", "plotVariable", "linearVariable", "lhsVariable", "rhsVariable",
		"xBox", "outerOperatorsFrame", "formulaFrame", "lhsEntry", "modelTypeVariable", "modelTypeFrame",
		"subdialog", "subButtonsFrame", "onHelp", "correlationsVariable", "screeplotVariable", "addPCVariable",
		"principalComponents", "validationVariable", "jackknifeVariable", "pcrplsrVariable", "addCompVariable",
		"validationFrame", "pcrplsrFrame", "contrVariable", "regVariable", "typeVariable", "typeVariable",
		"typeVariable", "typeRVariable", "linearModelANOVA", "linearModel", "contrFrame", "lineTypeVariable",
		"onCancel", "lineTypeFrame", "stackedVariable", "commonscaleVariable", "my.lm", "plottypeVariable",
		"plottypeFrame", "label.formatVariable", "zoomedVariable", "discreteVariable", "tmp", "scaleFrame",
		"meansVariable", "boxPlot", "fullmodelVariable", ".commander", "fittedVariable", "residualsVariable",
		"stdresVariable", "studresVariable", "pearsonVariable", "spearsonVariable", "hatvaluesVariable",
		"dffitsVariable", "cookdVariable", "obsNumbersVariable", "selectFrame", "typeVariable", "extrapVariable",
		"tukeyTestsVariable", "tukeyGroupsVariable", "bonferroniTestsVariable", "bonferroniGroupsVariable",
		"fisherTestsVariable", "fisherGroupsVariable", "tukeyFrame", "bonferroniFrame", "fisherFrame",
		"storeVariable", "displayVariable", "axis.crossVariable", "namesVariable", "spectraVariable",
		"regionsVariable", "contoursVariable", "samplesVariable", "logVariable", "logFrame", "rgl.cur",
		"outmat,rss,rsq,adjr2", "cp", ".x", "type1Variable", "type2Variable", "type3Variable", "mix.model",
		"base", "high", "newDataSet", ".activeDataSet", ".activeModel", "outmat","rss",
		"rsq","adjr2","pushViewport","viewport","upViewport","pressresVariable","presspredVariable",
		 "selectFrame1", "selectFrame2", "selectFrame3", "selectFrame4", "selectFrame5", "selectFrame6",
		 ".groups",".levels","multinom","typeFrame", "tkget", "tktag.add", "tkyview.moveto"))
